@@ -1,34 +1,46 @@
 <?php
 /*
- * Copyright (C) 2005 - 2008  Zarafa B.V.
- *
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
  * as published by the Free Software Foundation with the following additional 
  * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
  * 
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of the Program
- * under the AGPL does not imply a trademark license. Therefore any rights,
- * title and interest in our trademarks remain entirely with us.
- * However, if you propagate an unmodified version of the Program you are 
- * required to use the term "Zarafa" to indicate that you distribute the 
- * Program. Furthermore you may use our trademarks where it is necessary to 
- * indicate the intended purpose of a product or service provided you use it in 
- * accordance with honest practices in industrial or commercial matters.
- * If you want to propagate modified versions of the Program under the name
- * "Zarafa" or "Zarafa Server", you may only do so if you have a written
- * permission by Zarafa B.V. (to acquire a permission please contact Zarafa at
- * trademark@zarafa.com).
- * The user interface of the software displays a attribution notice containing
- * the term "Zarafa" and/or the Logo of Zarafa. You have to preserve these
- * attribution notices when you propagate unmodified or modified versions of
- * the Program.
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- * 
+ *  
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
@@ -582,4 +594,22 @@ define('SYNC_DEFER_CONFIG',                     0x20000);
 define('SYNC_FORCE_UNICODE',                    0x40000); // Forces server to return Unicode properties
 
 define('EMS_AB_ADDRESS_LOOKUP',					0x00000001); // Flag for resolvename to resolve only exact matches
+
+define('TBL_BATCH', 							0x00000002); // Batch multiple table commands
+
+/* Flags for recipients in exceptions */
+define('recipSendable',							0x00000001);	// sendable attendee.
+define('recipOrganizer',						0x00000002);	// meeting organizer
+define('recipExceptionalResponse',				0x00000010);	// attendee gave a response for the exception
+define('recipExceptionalDeleted',				0x00000020);	// recipientRow exists, but it is treated as if the corresponding recipient is deleted from meeting
+define('recipOriginal',							0x00000100);	// recipient is an original Attendee
+define('recipReserved',							0x00000200);	
+
+/* Flags which indicates type of Meeting Object */
+define('mtgEmpty',								0x00000000);	// Unspecified.
+define('mtgRequest',							0x00000001);	// Initial meeting request.
+define('mtgFull',								0x00010000);	// Full update.
+define('mtgInfo',								0x00020000);	// Informational update.
+define('mtgOutOfDate',							0x00080000);	// A newer Meeting Request object or Meeting Update object was received after this one.
+define('mtgDelegatorCopy',						0x00100000);	// This is set on the delegator's copy when a delegate will handle meeting-related objects.
 ?>
