@@ -1,34 +1,46 @@
 <?php
 /*
- * Copyright (C) 2005 - 2008  Zarafa B.V.
- *
+ * Copyright 2005 - 2009  Zarafa B.V.
+ * 
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Affero General Public License, version 3, 
  * as published by the Free Software Foundation with the following additional 
  * term according to sec. 7:
+ *  
+ * According to sec. 7 of the GNU Affero General Public License, version
+ * 3, the terms of the AGPL are supplemented with the following terms:
  * 
- * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of the Program
- * under the AGPL does not imply a trademark license. Therefore any rights,
- * title and interest in our trademarks remain entirely with us.
- * However, if you propagate an unmodified version of the Program you are 
- * required to use the term "Zarafa" to indicate that you distribute the 
- * Program. Furthermore you may use our trademarks where it is necessary to 
- * indicate the intended purpose of a product or service provided you use it in 
- * accordance with honest practices in industrial or commercial matters.
- * If you want to propagate modified versions of the Program under the name
- * "Zarafa" or "Zarafa Server", you may only do so if you have a written
- * permission by Zarafa B.V. (to acquire a permission please contact Zarafa at
- * trademark@zarafa.com).
- * The user interface of the software displays a attribution notice containing
- * the term "Zarafa" and/or the Logo of Zarafa. You have to preserve these
- * attribution notices when you propagate unmodified or modified versions of
- * the Program.
+ * "Zarafa" is a registered trademark of Zarafa B.V. The licensing of
+ * the Program under the AGPL does not imply a trademark license.
+ * Therefore any rights, title and interest in our trademarks remain
+ * entirely with us.
+ * 
+ * However, if you propagate an unmodified version of the Program you are
+ * allowed to use the term "Zarafa" to indicate that you distribute the
+ * Program. Furthermore you may use our trademarks where it is necessary
+ * to indicate the intended purpose of a product or service provided you
+ * use it in accordance with honest practices in industrial or commercial
+ * matters.  If you want to propagate modified versions of the Program
+ * under the name "Zarafa" or "Zarafa Server", you may only do so if you
+ * have a written permission by Zarafa B.V. (to acquire a permission
+ * please contact Zarafa at trademark@zarafa.com).
+ * 
+ * The interactive user interface of the software displays an attribution
+ * notice containing the term "Zarafa" and/or the logo of Zarafa.
+ * Interactive user interfaces of unmodified and modified versions must
+ * display Appropriate Legal Notices according to sec. 5 of the GNU
+ * Affero General Public License, version 3, when you propagate
+ * unmodified or modified versions of the Program. In accordance with
+ * sec. 7 b) of the GNU Affero General Public License, version 3, these
+ * Appropriate Legal Notices must retain the logo of Zarafa or display
+ * the words "Initial Development by Zarafa" if the display of the logo
+ * is not reasonably feasible for technical reasons."
  * 
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Affero General Public License for more details.
- * 
+ *  
  * You should have received a copy of the GNU Affero General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  * 
@@ -935,6 +947,7 @@ define('PR_CONTACT_DEFAULT_ADDRESS_INDEX'             ,mapi_prop_tag(PT_LONG,
 define('PR_CONTACT_EMAIL_ADDRESSES'                   ,mapi_prop_tag(PT_MV_TSTRING,  0x3A56));
 define('PR_CONTACT_EMAIL_ADDRESSES_W'                 ,mapi_prop_tag(PT_MV_UNICODE,  0x3A56));
 define('PR_CONTACT_EMAIL_ADDRESSES_A'                 ,mapi_prop_tag(PT_MV_STRING8,  0x3A56));
+define('PR_ATTACHMENT_CONTACTPHOTO'                   ,mapi_prop_tag(PT_BOOLEAN,     0x7FFF));
 
 
 define('PR_COMPANY_MAIN_PHONE_NUMBER'                 ,mapi_prop_tag(PT_TSTRING,     0x3A57));
@@ -1172,6 +1185,7 @@ define('PR_EC_RECIPIENT_HISTORY'                      ,mapi_prop_tag(PT_STRING8,
 define('PR_EC_STATSTABLE_SYSTEM'		, mapi_prop_tag(PT_OBJECT,		PR_EC_BASE+0x30));
 define('PR_EC_STATSTABLE_SESSIONS'		, mapi_prop_tag(PT_OBJECT,		PR_EC_BASE+0x31));
 define('PR_EC_STATSTABLE_USERS'			, mapi_prop_tag(PT_OBJECT,		PR_EC_BASE+0x32));
+define('PR_EC_STATSTABLE_COMPANY'		, mapi_prop_tag(PT_OBJECT,		PR_EC_BASE+0x33));
 
 define('PR_EC_STATS_SYSTEM_DESCRIPTION'	,mapi_prop_tag(PT_STRING8,	PR_EC_BASE+0x40));
 define('PR_EC_STATS_SYSTEM_VALUE'		,mapi_prop_tag(PT_STRING8,	PR_EC_BASE+0x41));
@@ -1222,4 +1236,12 @@ define('PR_PROCESSED', mapi_prop_tag(PT_BOOLEAN, 0x7D01));
 define('PR_DELEGATES_SEE_PRIVATE', mapi_prop_tag(PT_MV_LONG, 0x686B));
 define('PR_SCHDINFO_DELEGATE_ENTRYIDS', mapi_prop_tag(PT_MV_BINARY, 0x6845));
 define('PR_SCHDINFO_DELEGATE_NAMES', mapi_prop_tag(PT_MV_STRING8, 0x6844));
+
+// properties required in Reply mail.
+define('PR_INTERNET_REFERENCES', mapi_prop_tag(PT_STRING8, 0x1039));
+define('PR_IN_REPLY_TO_ID', mapi_prop_tag(PT_STRING8, 0x1042));
+define('PR_INTERNET_MESSAGE_ID', mapi_prop_tag(PT_STRING8, 0x1035));
+
+// for hidden folders
+define('PR_ATTR_HIDDEN', mapi_prop_tag(PT_BOOLEAN, 0x10F4));
 ?>
\ No newline at end of file
